@@ -27,6 +27,7 @@
 #endif
 
 #include <errno.h>
+#include <string.h>
 
 #include <openobex/obex.h>
 #include <openobex/obex_const.h>
@@ -44,56 +45,56 @@
 
 #define OPP_CHANNEL	9
 #define OPP_RECORD "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>	\
-<record>									\
-  <attribute id=\"0x0001\">							\
-    <sequence>									\
-      <uuid value=\"0x1105\"/>							\
-    </sequence>									\
-  </attribute>									\
-										\
-  <attribute id=\"0x0004\">							\
-    <sequence>									\
-      <sequence>								\
-        <uuid value=\"0x0100\"/>						\
-      </sequence>								\
-      <sequence>								\
-        <uuid value=\"0x0003\"/>						\
-        <uint8 value=\"%u\" name=\"channel\"/>					\
-      </sequence>								\
-      <sequence>								\
-        <uuid value=\"0x0008\"/>						\
-      </sequence>								\
-    </sequence>									\
-  </attribute>									\
-										\
-  <attribute id=\"0x0009\">							\
-    <sequence>									\
-      <sequence>								\
-        <uuid value=\"0x1105\"/>						\
-        <uint16 value=\"0x0100\" name=\"version\"/>				\
-      </sequence>								\
-    </sequence>									\
-  </attribute>									\
-										\
-  <attribute id=\"0x0100\">							\
-    <text value=\"%s\" name=\"name\"/>						\
-  </attribute>									\
-										\
-  <attribute id=\"0x0303\">							\
-    <sequence>									\
-      <uint8 value=\"0x01\"/>							\
-      <uint8 value=\"0x01\"/>							\
-      <uint8 value=\"0x02\"/>							\
-      <uint8 value=\"0x03\"/>							\
-      <uint8 value=\"0x04\"/>							\
-      <uint8 value=\"0x05\"/>							\
-      <uint8 value=\"0x06\"/>							\
-      <uint8 value=\"0xff\"/>							\
-    </sequence>									\
-  </attribute>									\
+<record>							\
+  <attribute id=\"0x0001\">					\
+    <sequence>							\
+      <uuid value=\"0x1105\"/>					\
+    </sequence>							\
+  </attribute>							\
+								\
+  <attribute id=\"0x0004\">					\
+    <sequence>							\
+      <sequence>						\
+        <uuid value=\"0x0100\"/>				\
+      </sequence>						\
+      <sequence>						\
+        <uuid value=\"0x0003\"/>				\
+        <uint8 value=\"%u\" name=\"channel\"/>			\
+      </sequence>						\
+      <sequence>						\
+        <uuid value=\"0x0008\"/>				\
+      </sequence>						\
+    </sequence>							\
+  </attribute>							\
+								\
+  <attribute id=\"0x0009\">					\
+    <sequence>							\
+      <sequence>						\
+        <uuid value=\"0x1105\"/>				\
+        <uint16 value=\"0x0100\" name=\"version\"/>		\
+      </sequence>						\
+    </sequence>							\
+  </attribute>							\
+								\
+  <attribute id=\"0x0100\">					\
+    <text value=\"%s\" name=\"name\"/>				\
+  </attribute>							\
+								\
+  <attribute id=\"0x0303\">					\
+    <sequence>							\
+      <uint8 value=\"0x01\"/>					\
+      <uint8 value=\"0x01\"/>					\
+      <uint8 value=\"0x02\"/>					\
+      <uint8 value=\"0x03\"/>					\
+      <uint8 value=\"0x04\"/>					\
+      <uint8 value=\"0x05\"/>					\
+      <uint8 value=\"0x06\"/>					\
+      <uint8 value=\"0xff\"/>					\
+    </sequence>							\
+  </attribute>							\
 </record>"
 
-static gpointer opp_connect(struct obex_session *os, int *err)
+static void *opp_connect(struct obex_session *os, int *err)
 {
 	manager_register_transfer(os);
 
@@ -103,17 +104,17 @@ static gpointer opp_connect(struct obex_session *os, int *err)
 	return NULL;
 }
 
-static void opp_progress(struct obex_session *os, gpointer user_data)
+static void opp_progress(struct obex_session *os, void *user_data)
 {
 	manager_emit_transfer_progress(os);
 }
 
-static gint opp_chkput(struct obex_session *os, gpointer user_data)
+static int opp_chkput(struct obex_session *os, void *user_data)
 {
-	gchar *folder, *name;
-	gchar *path;
-	gint32 time;
-	gint ret;
+	char *folder, *name;
+	char *path;
+	int32_t time;
+	int ret;
 
 	if (obex_get_size(os) == OBJECT_SIZE_DELETE)
 		return -EINVAL;
@@ -136,11 +137,14 @@ static gint opp_chkput(struct obex_session *os, gpointer user_data)
 		name = g_strdup(obex_get_name(os));
 
 skip_auth:
+	if (name == NULL || strlen(name) == 0)
+		return -EBADR;
+
 	path = g_build_filename(folder, name, NULL);
 
 	manager_emit_transfer_started(os);
 
-	ret = obex_prepare_put(os, path);
+	ret = obex_put_stream_start(os, path);
 
 	g_free(path);
 	g_free(folder);
@@ -149,7 +153,7 @@ skip_auth:
 	return ret;
 }
 
-static int opp_put(struct obex_session *os, gpointer user_data)
+static int opp_put(struct obex_session *os, void *user_data)
 {
 	const char *name = obex_get_name(os);
 	const char *folder = obex_get_root_folder(os);
@@ -164,7 +168,7 @@ static int opp_put(struct obex_session *os, gpointer user_data)
 }
 
 static int opp_get(struct obex_session *os, obex_object_t *obj,
-		gpointer user_data)
+			gboolean *stream, void *user_data)
 {
 	const char *type;
 
@@ -177,26 +181,29 @@ static int opp_get(struct obex_session *os, obex_object_t *obj,
 		return -EPERM;
 
 	if (g_str_equal(type, VCARD_TYPE)) {
-		if (obex_stream_start(os, VCARD_FILE, NULL) < 0)
+		if (obex_get_stream_start(os, VCARD_FILE) < 0)
 			return -ENOENT;
 
 	} else
 		return -EPERM;
 
+	if (stream)
+		*stream = TRUE;
+
 	return 0;
 }
 
-static void opp_disconnect(struct obex_session *os, gpointer user_data)
+static void opp_disconnect(struct obex_session *os, void *user_data)
 {
 	manager_unregister_transfer(os);
 }
 
-static void opp_reset(struct obex_session *os, gpointer user_data)
+static void opp_reset(struct obex_session *os, void *user_data)
 {
 	manager_emit_transfer_completed(os);
 }
 
-struct obex_service_driver driver = {
+static struct obex_service_driver driver = {
 	.name = "Object Push server",
 	.service = OBEX_OPP,
 	.channel = OPP_CHANNEL,
